@@ -3,10 +3,6 @@
 #include "Imlib.h"
 #include "Imlib_private.h"
 
-#ifdef __EMX__
-extern const char *__XOS2RedirRoot(const char *);
-#endif
-
 static int PaletteLUTGet(ImlibData *id);
 static void PaletteLUTSet(ImlibData *id);
 
@@ -81,7 +77,7 @@ PaletteLUTSet(ImlibData *id)
 {
   Atom                to_set;
   unsigned char       *prop;
-  int                 i, j, r, g, b;
+  int                 i, j;
   
   to_set = XInternAtom(id->x.disp, "_IMLIB_COLORMAP", False);
   prop = malloc((id->num_colors * 4) + 1 + (32 * 32 * 32));
@@ -165,14 +161,7 @@ Imlib_load_colors(ImlibData * id, char *file)
   int                 r, g, b;
   int                 rr, gg, bb;
 
-#ifndef __EMX__
   f = fopen(file, "r");
-#else
-  if (*file == '/')
-  f = fopen(__XOS2RedirRoot(file), "rt");
- else
-  f = fopen(file, "rt");
-#endif
   if (!f)
     {
       fprintf(stderr, "ImLib ERROR: Cannot find palette file %s\n", file);
